@@ -9,6 +9,9 @@ from mtq.defaults import _collection_base, _qsize, _workersize, _logsize, \
     _task_map
 from mtq.utils import ensure_capped_collection, now
 from time import mktime
+import pymongo
+from pymongo import ASCENDING
+import time
 
 class MTQConnection(object):
     '''
@@ -22,21 +25,21 @@ class MTQConnection(object):
     
     ..sealso: MTQConnection.default, MTQConnection.from_config
     '''
-    
+
     def __init__(self, db, collection_base=_collection_base, qsize=_qsize,
                  workersize=_workersize, logsize=_logsize, extra_lognames=()):
         self.db = db
         self.collection_base = collection_base
         self.qsize = qsize
-        self.workersize = workersize 
+        self.workersize = workersize
         self.logsize = logsize
         self._task_map = _task_map.copy()
         self.extra_lognames = extra_lognames
-    
+
     def _destroy(self):
         'Destroy ALL data'
         self.db.connection.drop_database(self.db)
-        
+
     @classmethod
     def default(cls):
         '''
@@ -64,9 +67,9 @@ class MTQConnection(object):
 
         if client is None:
             client = MongoClient(config.get('DB_HOST', 'mongodb://localhost/?journal=true'), tz_aware=True)
-        
+
         db = getattr(client, config.get('DB', 'mq'))
-        
+
         base = config.get('COLLECTION_BASE', _collection_base)
         qsize = config.get('COLLECTION_SIZE', _qsize)
         return cls(db, base, qsize, extra_lognames=config.get('extra_lognames', ()))
@@ -77,7 +80,7 @@ class MTQConnection(object):
         '''
         job = self.get_job(job_id)
         return job.stream()
-    
+
     def worker_stream(self, worker_name=None,
                             worker_id=None):
         '''
@@ -85,7 +88,7 @@ class MTQConnection(object):
         '''
         worker = self.get_worker(worker_name, worker_id)
         return worker.stream()
-    
+
     @property
     def queue_collection(self):
         'The collection to push jobs to'
@@ -116,7 +119,7 @@ class MTQConnection(object):
         '''
         return a mongodb query dict to get the next task in the queue 
         '''
-        query.update({ 
+        query.update({
                 'priority':{'$gte':priority},
                 'process_after': {'$lte':now()},
                  })
@@ -124,16 +127,16 @@ class MTQConnection(object):
             query['failed'] = True
         elif processed is not None:
             query['processed'] = processed
-        
+
         if queues:
             if len(queues) == 1:
                 query['qname'] = queues[0]
             else:
                 query['qname'] = {'$in': queues}
-            
+
         query.update(self.make_tag_query(tags))
         return query
-    
+
     def make_tag_query(self, tags):
         'Query for tags'
         if not tags:
@@ -143,6 +146,35 @@ class MTQConnection(object):
         else:
             return {'$and': [{'tags':tag} for tag in tags]}
 
+
+    def add_mutex(self, query):
+        running_query = self.make_query(None, None, processed=True)
+        cursor = self.queue_collection.find(running_query, fields={'mutex':1, '_id':0})
+
+        if not cursor.count():
+            return
+
+        # Populate dictionary of mutex_key:count
+        mutex = {}
+
+        # Iterate over running jobs
+        for item in cursor:
+            item_mutex = item.get('mutex', {})
+            if not item_mutex: continue
+            mutext_key = item_mutex.get('key')
+            if not mutext_key: continue
+            mutex.setdefault(mutext_key, 0)
+            mutex[mutext_key] += 1
+
+        # Query should inclue jobs with no mutex key or where its key is not in any running jobs
+        _or = [{'mutex': None}, {'mutex': {'$exists': False}}, {'mutex.key': {'$nin': mutex.keys()}}]
+
+        # Query should inclue jobs where the mutex.count is > the # already running
+        for key, already_running in mutex.items():
+            _or.append({'mutex.key': key, 'mutex.count': {'$gt': already_running}})
+
+        query['$or'] = _or
+
     def pop_item(self, worker_id, queues, tags, priority=0, failed=False):
         'Pop an item from the queue'
         n = now()
@@ -151,30 +183,32 @@ class MTQConnection(object):
                           'started_at_': mktime(n.timetuple()),
                           'worker_id':worker_id}
                   }
-        
-        query = self.make_query(queues, tags, priority, failed) 
-        doc = self.queue_collection.find_and_modify(query, update)
-        
+
+        query = self.make_query(queues, tags, priority, failed)
+        self.add_mutex(query)
+
+        doc = self.queue_collection.find_and_modify(query, update, sort=[('enqueued_at', ASCENDING)])
+
         if doc is None:
             return None
         else:
             return mtq.Job(self, doc)
-    
+
     def _items_cursor(self, queues, tags, priority=0, processed=False, limit=None, reverse=False):
         query = self.make_query(queues, tags, priority, processed=processed)
         cursor = self.queue_collection.find(query)
-        
+
         if reverse:
             cursor = cursor.sort('enqueued_at', -1)
         if limit:
             cursor = cursor.limit(limit)
-            
+
         return cursor
-            
+
     def items(self, queues, tags, priority=0, processed=False, limit=None, reverse=False):
         cursor = self._items_cursor(queues, tags, priority, processed, limit, reverse)
         return [mtq.Job(self, doc) for doc in cursor]
-    
+
     def queue(self, name='default', tags=(), priority=0):
         '''
         Create a queue object
@@ -183,11 +217,11 @@ class MTQConnection(object):
         :param tags: default tags to give to jobs 
         :param priority: (not implemented yet)
         '''
-        
-        return mtq.Queue(self, name, tags, priority)
-    
 
-        
+        return mtq.Queue(self, name, tags, priority)
+
+
+
     def new_worker(self, queues=(), tags=(), priority=0, silence=False, log_worker_output=False, poll_interval=3, args=None):
         '''
         Create a worker object
@@ -199,12 +233,12 @@ class MTQConnection(object):
         '''
         worker = mtq.Worker(self, queues, tags, priority,
                          log_worker_output=log_worker_output,
-                         silence=silence, extra_lognames=self.extra_lognames,poll_interval=poll_interval)
-        
+                         silence=silence, extra_lognames=self.extra_lognames, poll_interval=poll_interval)
+
         self.args = args
         self.worker = worker
         return worker
-    
+
     #===========================================================================
     # Workers
     #===========================================================================
@@ -220,7 +254,7 @@ class MTQConnection(object):
         collection = self.queue_collection
         qnames = collection.find().distinct('qname')
         return [mtq.Queue(self, qname) for qname in qnames]
-    
+
     @property
     def workers(self):
         '''
@@ -230,8 +264,8 @@ class MTQConnection(object):
         '''
         collection = self.worker_collection
         return [mtq.WorkerProxy(self, item) for item in collection.find({'working':True})]
-    
-        
+
+
     def get_job(self, job_id):
         '''
         retrieve a job
@@ -240,9 +274,9 @@ class MTQConnection(object):
         doc = collection.find_one({'_id':job_id})
         if doc is None:
             return None
-        
+
         return mtq.Job(self, doc)
-    
+
     def get_worker(self, worker_name=None, worker_id=None):
         '''
         retrieve a worker
@@ -257,15 +291,15 @@ class MTQConnection(object):
         doc = coll.find_one(query)
         if doc is None:
             raise TypeError('Could not find worker')
-        
+
         return mtq.WorkerProxy(self, doc)
-    
+
 
     #===========================================================================
     # Scheduler
     #===========================================================================
-    
+
     def scheduler(self):
         return mtq.Scheduler(self)
-    
-    
+
+
